Page 172 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 172

Home

    In 1966, Mr. Welch made a famous speech called
    "The Truth In Time" that struck at the very heart of the
    activities of the manipulators. In this speech, he
    concluded that there was a Master Conspiracy above the

    wealthy.
    In 1983 JBS staff member John F. McManus wrote a

    book about these powerful men entitled The Insiders. In
    a radio interview, Mr. McManus explained why he chose

    Welch, who, back in 1965, posited a theory that the
    world was in the grip of international financiers,

    wane an

    politicians, etc., who were not themselves Communists,
    but were in fact above the Communists.

    These were the people who finance Communism,
    help it, dignify it, keep it going. . . . These people
    themselves weren't Communist, but were part of a
    conspiracy that had actually brought Communism into
    existence back in the middle of the 1800s, and were

    keeping it in existence today, and were using
    Communism to take over nation after nation on the route

    toward a world government. Robert Welch called these
    powerful individuals, "The Insiders."”

    As a result of the leadership of Robert Welch and the
    Council of The John Birch Society, the Society soon
    attracted tens of thousands of dedicated members

    167

    A New Movement in History

    Communists that had brought them to power, and that

    this Master Conspiracy was made up of the super-

    this title for his book:

    The title The Insiders was borrowed from Robert

    and were using

    throughout the United States. The truth about the